Version 3.0.2 — Invenio 3.4.0a8 documentation

# Version 3.0.2

Released 2019-07-15

Invenio v3.0.2 fixes two security issues.

## Security fixes

- Invenio-App: Fixed a Host header injection vulnerability.

- Invenio-Records: Fixed a Cross-Site Scripting vulnerability in the administration interface.

## Maintenance policy

Invenio v3.0 will be supported with bug and security fixes until the release of Invenio v3.2 and minimum until 2019-06-07.